@@ -1,6 +1,6 @@
 <?php
 /**
- * $Horde: turba/lib/Turba.php,v 1.59.4.48 2010-05-12 10:00:22 jan Exp $
+ * $Horde: turba/lib/Turba.php,v 1.59.4.50 2010/11/26 09:19:38 jan Exp $
  *
  * @package Turba
  */
@@ -147,6 +147,15 @@ class Turba {
             }
         }
 
+        /* In case of shares select first user owned address book as default */
+        if (!empty($_SESSION['turba']['has_share'])) {
+            $owned_shares = Turba::listShares(true);
+
+            if (!is_a($owned_shares, 'PEAR_Error') && count($owned_shares) > 0) {
+                return key($owned_shares);
+            }
+        }
+
         reset($GLOBALS['cfgSources']);
         return key($GLOBALS['cfgSources']);
     }
